==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/networkanalytics/kotlin/inputs/DataProductNetworkAclsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.networkanalytics.kotlin.inputs

import com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs.builder
import com.pulumi.azurenative.networkanalytics.kotlin.enums.DefaultAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Data Product Network rule set
 * @property allowedQueryIpRangeList The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
 * @property defaultAction Default Action
 * @property ipRules IP rule with specific IP or IP range in CIDR format.
 * @property virtualNetworkRule Virtual Network Rule
 */
public data class DataProductNetworkAclsArgs(
    public val allowedQueryIpRangeList: Output<List<String>>,
    public val defaultAction: Output<Either<String, DefaultAction>>,
    public val ipRules: Output<List<IPRulesArgs>>,
    public val virtualNetworkRule: Output<List<VirtualNetworkRuleArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs> {
    override fun toJava(): com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs =
        com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs.builder()
            .allowedQueryIpRangeList(
                allowedQueryIpRangeList.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .defaultAction(
                defaultAction.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipRules(
                ipRules.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .virtualNetworkRule(
                virtualNetworkRule.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataProductNetworkAclsArgs].
 */
@PulumiTagMarker
public class DataProductNetworkAclsArgsBuilder internal constructor() {
    private var allowedQueryIpRangeList: Output<List<String>>? = null

    private var defaultAction: Output<Either<String, DefaultAction>>? = null

    private var ipRules: Output<List<IPRulesArgs>>? = null

    private var virtualNetworkRule: Output<List<VirtualNetworkRuleArgs>>? = null

    /**
     * @param value The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("kywcnypqpxngmnhb")
    public suspend fun allowedQueryIpRangeList(`value`: Output<List<String>>) {
        this.allowedQueryIpRangeList = value
    }

    @JvmName("ooxkjhdnxptxnviy")
    public suspend fun allowedQueryIpRangeList(vararg values: Output<String>) {
        this.allowedQueryIpRangeList = Output.all(values.asList())
    }

    /**
     * @param values The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("ehmkbgxmvoxoblqh")
    public suspend fun allowedQueryIpRangeList(values: List<Output<String>>) {
        this.allowedQueryIpRangeList = Output.all(values)
    }

    /**
     * @param value Default Action
     */
    @JvmName("cewceutevmjetgif")
    public suspend fun defaultAction(`value`: Output<Either<String, DefaultAction>>) {
        this.defaultAction = value
    }

    /**
     * @param value IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("ldrvkejkdjttpedu")
    public suspend fun ipRules(`value`: Output<List<IPRulesArgs>>) {
        this.ipRules = value
    }

    @JvmName("plfhtkhldwfvtxvg")
    public suspend fun ipRules(vararg values: Output<IPRulesArgs>) {
        this.ipRules = Output.all(values.asList())
    }

    /**
     * @param values IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("fkiyvgmlmgpcawmo")
    public suspend fun ipRules(values: List<Output<IPRulesArgs>>) {
        this.ipRules = Output.all(values)
    }

    /**
     * @param value Virtual Network Rule
     */
    @JvmName("ipccjlvdekoibjpe")
    public suspend fun virtualNetworkRule(`value`: Output<List<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRule = value
    }

    @JvmName("hdtjkuxtjavnmwob")
    public suspend fun virtualNetworkRule(vararg values: Output<VirtualNetworkRuleArgs>) {
        this.virtualNetworkRule = Output.all(values.asList())
    }

    /**
     * @param values Virtual Network Rule
     */
    @JvmName("qgiyciytnifpdjlf")
    public suspend fun virtualNetworkRule(values: List<Output<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRule = Output.all(values)
    }

    /**
     * @param value The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("lrobtvwdawddtmgy")
    public suspend fun allowedQueryIpRangeList(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedQueryIpRangeList = mapped
    }

    /**
     * @param values The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("mgaxuifcoyoglspd")
    public suspend fun allowedQueryIpRangeList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedQueryIpRangeList = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("oigwtjkfpbmtxsrq")
    public suspend fun defaultAction(`value`: Either<String, DefaultAction>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("jlxtsqwkatfutihu")
    public fun defaultAction(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DefaultAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("liijbsbgyohkqbmv")
    public fun defaultAction(`value`: DefaultAction) {
        val toBeMapped = Either.ofRight<String, DefaultAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("dnevtyntrbqgufcq")
    public suspend fun ipRules(`value`: List<IPRulesArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("viqmsreaavhuxbti")
    public suspend fun ipRules(argument: List<suspend IPRulesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IPRulesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("srkqshhyumytdyxo")
    public suspend fun ipRules(vararg argument: suspend IPRulesArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IPRulesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("dbaxtaqpymbgqqgr")
    public suspend fun ipRules(argument: suspend IPRulesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IPRulesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param values IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("xoeigppvwdgccguf")
    public suspend fun ipRules(vararg values: IPRulesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param value Virtual Network Rule
     */
    @JvmName("jmkvrpjlutcdekxs")
    public suspend fun virtualNetworkRule(`value`: List<VirtualNetworkRuleArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("fkkxgenjxltvmkws")
    public suspend
    fun virtualNetworkRule(argument: List<suspend VirtualNetworkRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("gjogixavfrtuiqgd")
    public suspend fun virtualNetworkRule(
        vararg
        argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("clcdessagekoxeng")
    public suspend
    fun virtualNetworkRule(argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VirtualNetworkRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param values Virtual Network Rule
     */
    @JvmName("bjxowbnxphpootxj")
    public suspend fun virtualNetworkRule(vararg values: VirtualNetworkRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworkRule = mapped
    }

    internal fun build(): DataProductNetworkAclsArgs = DataProductNetworkAclsArgs(
        allowedQueryIpRangeList = allowedQueryIpRangeList ?: throw
            PulumiNullFieldException("allowedQueryIpRangeList"),
        defaultAction = defaultAction ?: throw PulumiNullFieldException("defaultAction"),
        ipRules = ipRules ?: throw PulumiNullFieldException("ipRules"),
        virtualNetworkRule = virtualNetworkRule ?: throw PulumiNullFieldException("virtualNetworkRule"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/networkanalytics/kotlin/inputs/DataProductNetworkAclsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.networkanalytics.kotlin.inputs

import com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs.builder
import com.pulumi.azurenative.networkanalytics.kotlin.enums.DefaultAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Data Product Network rule set
 * @property allowedQueryIpRangeList The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
 * @property defaultAction Default Action
 * @property ipRules IP rule with specific IP or IP range in CIDR format.
 * @property virtualNetworkRule Virtual Network Rule
 */
public data class DataProductNetworkAclsArgs(
    public val allowedQueryIpRangeList: Output<List<String>>,
    public val defaultAction: Output<Either<String, DefaultAction>>,
    public val ipRules: Output<List<IPRulesArgs>>,
    public val virtualNetworkRule: Output<List<VirtualNetworkRuleArgs>>,
) : ConvertibleToJava<com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs> {
    override fun toJava(): com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs =
        com.pulumi.azurenative.networkanalytics.inputs.DataProductNetworkAclsArgs.builder()
            .allowedQueryIpRangeList(
                allowedQueryIpRangeList.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .defaultAction(
                defaultAction.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ipRules(
                ipRules.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .virtualNetworkRule(
                virtualNetworkRule.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [DataProductNetworkAclsArgs].
 */
@PulumiTagMarker
public class DataProductNetworkAclsArgsBuilder internal constructor() {
    private var allowedQueryIpRangeList: Output<List<String>>? = null

    private var defaultAction: Output<Either<String, DefaultAction>>? = null

    private var ipRules: Output<List<IPRulesArgs>>? = null

    private var virtualNetworkRule: Output<List<VirtualNetworkRuleArgs>>? = null

    /**
     * @param value The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("gitdadyywbkpijhp")
    public suspend fun allowedQueryIpRangeList(`value`: Output<List<String>>) {
        this.allowedQueryIpRangeList = value
    }

    @JvmName("ugvqhcwqrdowfmqw")
    public suspend fun allowedQueryIpRangeList(vararg values: Output<String>) {
        this.allowedQueryIpRangeList = Output.all(values.asList())
    }

    /**
     * @param values The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("lqbhntlaodpmhbys")
    public suspend fun allowedQueryIpRangeList(values: List<Output<String>>) {
        this.allowedQueryIpRangeList = Output.all(values)
    }

    /**
     * @param value Default Action
     */
    @JvmName("ceaijbydhwxffcdy")
    public suspend fun defaultAction(`value`: Output<Either<String, DefaultAction>>) {
        this.defaultAction = value
    }

    /**
     * @param value IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("rrygfdgfcuyarqhu")
    public suspend fun ipRules(`value`: Output<List<IPRulesArgs>>) {
        this.ipRules = value
    }

    @JvmName("rtgnaekjpqpvgwya")
    public suspend fun ipRules(vararg values: Output<IPRulesArgs>) {
        this.ipRules = Output.all(values.asList())
    }

    /**
     * @param values IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("cdopjsrenhtiloqf")
    public suspend fun ipRules(values: List<Output<IPRulesArgs>>) {
        this.ipRules = Output.all(values)
    }

    /**
     * @param value Virtual Network Rule
     */
    @JvmName("fvmgweoneabhhjgr")
    public suspend fun virtualNetworkRule(`value`: Output<List<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRule = value
    }

    @JvmName("wcufadfbfvjnkhik")
    public suspend fun virtualNetworkRule(vararg values: Output<VirtualNetworkRuleArgs>) {
        this.virtualNetworkRule = Output.all(values.asList())
    }

    /**
     * @param values Virtual Network Rule
     */
    @JvmName("xhfirrbwrsnisyou")
    public suspend fun virtualNetworkRule(values: List<Output<VirtualNetworkRuleArgs>>) {
        this.virtualNetworkRule = Output.all(values)
    }

    /**
     * @param value The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("klevdfksxuqorugh")
    public suspend fun allowedQueryIpRangeList(`value`: List<String>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedQueryIpRangeList = mapped
    }

    /**
     * @param values The list of query ips in the format of CIDR allowed to connect to query/visualization endpoint.
     */
    @JvmName("atvsgcuwmvmvamda")
    public suspend fun allowedQueryIpRangeList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedQueryIpRangeList = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("sfqijvkdahqggnsc")
    public suspend fun defaultAction(`value`: Either<String, DefaultAction>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("waigikqdatqdstng")
    public fun defaultAction(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DefaultAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value Default Action
     */
    @JvmName("ohdtbwkbmobdqvja")
    public fun defaultAction(`value`: DefaultAction) {
        val toBeMapped = Either.ofRight<String, DefaultAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.defaultAction = mapped
    }

    /**
     * @param value IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("euwkuucubdskhnjs")
    public suspend fun ipRules(`value`: List<IPRulesArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("slolqejinrbkkkgd")
    public suspend fun ipRules(argument: List<suspend IPRulesArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { IPRulesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("mwsdqncenhtrulnu")
    public suspend fun ipRules(vararg argument: suspend IPRulesArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { IPRulesArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param argument IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("wplbvoomtufkytxo")
    public suspend fun ipRules(argument: suspend IPRulesArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IPRulesArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.ipRules = mapped
    }

    /**
     * @param values IP rule with specific IP or IP range in CIDR format.
     */
    @JvmName("lxfqcaxdngibqqkh")
    public suspend fun ipRules(vararg values: IPRulesArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipRules = mapped
    }

    /**
     * @param value Virtual Network Rule
     */
    @JvmName("rheuhjbucclaajhl")
    public suspend fun virtualNetworkRule(`value`: List<VirtualNetworkRuleArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("khfwdomkdynsdrab")
    public suspend
    fun virtualNetworkRule(argument: List<suspend VirtualNetworkRuleArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("apduecmwfryxtmqo")
    public suspend fun virtualNetworkRule(
        vararg
        argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworkRuleArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param argument Virtual Network Rule
     */
    @JvmName("ltafcihqggdoywov")
    public suspend
    fun virtualNetworkRule(argument: suspend VirtualNetworkRuleArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VirtualNetworkRuleArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.virtualNetworkRule = mapped
    }

    /**
     * @param values Virtual Network Rule
     */
    @JvmName("qfnqwynerbrnmbhc")
    public suspend fun virtualNetworkRule(vararg values: VirtualNetworkRuleArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.virtualNetworkRule = mapped
    }

    internal fun build(): DataProductNetworkAclsArgs = DataProductNetworkAclsArgs(
        allowedQueryIpRangeList = allowedQueryIpRangeList ?: throw
            PulumiNullFieldException("allowedQueryIpRangeList"),
        defaultAction = defaultAction ?: throw PulumiNullFieldException("defaultAction"),
        ipRules = ipRules ?: throw PulumiNullFieldException("ipRules"),
        virtualNetworkRule = virtualNetworkRule ?: throw PulumiNullFieldException("virtualNetworkRule"),
    )
}
